@@ -40,6 +40,13 @@ def parse_bool(val):
     return _parse_with(val, type_util.is_bool, _parse_bool)
 
 
+def parse_date(val, format=None):
+    val = parse_datetime(val, format)
+    if val:
+        return val.date()
+    return None
+
+
 def _parse_datetime_with_format(val, format):
     try:
         return datetime.strptime(val, format)
@@ -136,15 +143,18 @@ def parse_int(val):
 
 
 def _parse_list(val, separator=None):
-    serializer = JSONSerializer()
-    try:
-        l = serializer.decode(val)
-        if type_util.is_list(l):
-            return l
-    except Exception:
-        if separator:
-            l = list(val.split(separator))
-            return l
+    if val.startswith('{') and val.endswith('}') or val.startswith('[') and val.endswith(']'):
+        try:
+            serializer = JSONSerializer()
+            l = serializer.decode(val)
+            if type_util.is_list(l):
+                return l
+            return None
+        except Exception:
+            pass
+    if separator:
+        l = list(val.split(separator))
+        return l
     return None
 
 
@@ -205,3 +215,8 @@ def parse_str(val):
     val = val.strip()
     val = ' '.join(val.split())
     return val
+
+
+def parse_uuid(val):
+    s = parse_str(val)
+    return s if type_util.is_uuid(s) else None
